## Copyright (C) 2008 Denis Sbragion
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
##(at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##
## This function is part of DRC - Digital room correction

##
## usage: ir = xosim(lpir,lpl,hpir,hpl,xof)
##
## Makes an LR24 xover simulation on two input impulse responses,
## returns the resulting combined impulse response.
##
## lpir: lowpass impulse response
## lpl: lowpass level
## hpir: highpass impulse response
## hpl: highpass level
## xof: xover frequency
##
## Example:
##
##  ir = xosim(lpir,lpl,hpir,hpl,200 / 20050)
##

function ir = xosim(lpir,lpl,hpir,hpl,xof)
	# Computes the low pass filter
	[lpb, lpa] = butter(2,xof);
	
	# Computes the high pass filter
	[hpb, hpa] = butter(2,xof,'high');
	
	# Computes the xover impulse response
	ir = filter(lpb,lpa,filter(lpb,lpa,lpir * lpl)) + filter(hpb,hpa,filter(hpb,hpa,hpir * hpl));
endfunction